package com.competition.adapter.app;

import com.competition.IAdapter;
import com.competition.adapter.BaseAdapter;
import com.competition.bean.DcFootTeam;
import com.competition.cache.FootCache;
import com.competition.service.IDcFootScheduleService;
import com.competition.service.IDcLotteryMatchService;
import com.competition.utils.SpringUtils;
import com.competition.utils.Utils;
import com.competition.utils.xml.parse.ByteCodeUtil;
import com.competition.utils.xml.parse.XmlBean;
import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Component;

@Component
public class AppFBMatchInfoQueryAdapter extends BaseAdapter implements IAdapter {

   @Resource
   private IDcLotteryMatchService lotteryMatchService;
   @Resource
   private IDcFootScheduleService footScheduleService;


   public XmlBean execute(XmlBean xmlBean) {
      XmlBean requestBean = xmlBean.getFirst("request");
      XmlBean queryBean = requestBean.getFirst("query");
      String issue = queryBean.attribute("issue");
      String lotteryCode = queryBean.attribute("lotteryCode");
      int quantity = Utils.formatInt(queryBean.attribute("quantity"), 3);
      if(!StringUtils.isBlank(issue) && !StringUtils.isBlank(lotteryCode)) {
         List list = this.lotteryMatchService.getFBAvgEuroOddsByIssue(lotteryCode, issue);
         if(list != null && list.size() != 0) {
            List ranks = this.lotteryMatchService.getFBTeamRankByIssue(lotteryCode, issue);
            XmlBean bean = this.buildXmlBean(list, issue, ranks, quantity, lotteryCode);
            return bean == null?this.returnErrorCodeBody("0999"):bean;
         } else {
            return this.returnErrorCodeBody("9000");
         }
      } else {
         return this.returnErrorCodeBody("0003");
      }
   }

   private XmlBean buildXmlBean(List list, String issue, List ranks, int quantity, String lotteryCode) {
      LinkedHashMap betRateMap = new LinkedHashMap();
      List betRateList = this.lotteryMatchService.getDcMatchBetRateByIssue(issue, lotteryCode);
      Iterator home;
      if(betRateList != null && betRateList.size() > 0) {
         home = betRateList.iterator();

         while(home.hasNext()) {
            Map mapss = (Map)home.next();
            betRateMap.put(mapss.get("scheduleId").toString(), mapss);
         }
      }

      HashMap mapss1 = new HashMap();
      Iterator guest;
      if(ranks != null) {
         guest = ranks.iterator();

         while(guest.hasNext()) {
            Map home1 = (Map)guest.next();
            mapss1.put(home1.get("sn").toString(), home1);
         }
      }

      home = null;
      guest = null;
      DecimalFormat format = new DecimalFormat("#.00");
      StringBuffer sb = new StringBuffer("<body>");
      Iterator var14 = list.iterator();

      while(var14.hasNext()) {
         Map map = (Map)var14.next();
         if(FootCache.CACHE_ALL_TEAM.containsKey(map.get("homeId").toString()) && FootCache.CACHE_ALL_TEAM.containsKey(map.get("guestId").toString())) {
            DcFootTeam home2 = (DcFootTeam)FootCache.CACHE_ALL_TEAM.get(map.get("homeId").toString());
            DcFootTeam guest1 = (DcFootTeam)FootCache.CACHE_ALL_TEAM.get(map.get("guestId").toString());
            sb.append("<odds");
            sb.append(" issue=\"" + issue + "\" ");
            sb.append(" scheduleid=\"" + map.get("scheduleId") + "\" ");
            sb.append(" sn=\"" + map.get("sn") + "\" ");
            sb.append(" homewin=\"" + (map.containsKey("homewin")?format.format(((BigDecimal)map.get("homewin")).doubleValue()):"") + "\" ");
            sb.append(" standoff=\"" + (map.containsKey("standoff")?format.format(((BigDecimal)map.get("standoff")).doubleValue()):"") + "\" ");
            sb.append(" guestwin=\"" + (map.containsKey("guestwin")?format.format(((BigDecimal)map.get("guestwin")).doubleValue()):"") + "\" ");
            sb.append(" homelogo=\"" + (home2 != null?home2.getFlag():"") + "\" ");
            sb.append(" guestlogo=\"" + (guest1 != null?guest1.getFlag():"") + "\" ");
            if(mapss1.containsKey(map.get("sn").toString())) {
               sb.append(" homeorder=\"" + ((Map)mapss1.get(map.get("sn").toString())).get("homeOrder") + "\" ");
               sb.append(" guestorder=\"" + ((Map)mapss1.get(map.get("sn").toString())).get("guestOrder") + "\" ");
            } else {
               sb.append(" homeorder=\"-\" ");
               sb.append(" guestorder=\"-\" ");
            }

            Map map2 = this.footScheduleService.countEachWinLoseFlat(home2.getTeamId().longValue(), guest1.getTeamId().longValue(), quantity);
            Map map3 = this.footScheduleService.countWinLoseFlat(home2.getTeamId().longValue(), quantity);
            Map map4 = this.footScheduleService.countWinLoseFlat(guest1.getTeamId().longValue(), quantity);
            this.check(map2);
            this.check(map3);
            this.check(map4);
            sb.append(" historyvs=\"" + map2.get("WIN") + "," + map2.get("FLAT") + "," + map2.get("LOSE") + "\" ");
            sb.append(" recentgrade=\"" + map3.get("WIN") + "," + map3.get("FLAT") + "," + map3.get("LOSE") + "," + map4.get("WIN") + "," + map4.get("FLAT") + "," + map4.get("LOSE") + "\" ");
            if(betRateMap.containsKey(map.get("scheduleId").toString())) {
               sb.append(" victoryRateR=\"" + ((Map)betRateMap.get(map.get("scheduleId").toString())).get("r3") + "\" ");
               sb.append(" drawRateR=\"" + ((Map)betRateMap.get(map.get("scheduleId").toString())).get("r1") + "\" ");
               sb.append(" loseRateR=\"" + ((Map)betRateMap.get(map.get("scheduleId").toString())).get("r0") + "\" ");
               sb.append(" victoryRate=\"" + ((Map)betRateMap.get(map.get("scheduleId").toString())).get("s3") + "\" ");
               sb.append(" drawRate=\"" + ((Map)betRateMap.get(map.get("scheduleId").toString())).get("s1") + "\" ");
               sb.append(" loseRate=\"" + ((Map)betRateMap.get(map.get("scheduleId").toString())).get("s0") + "\" ");
            } else {
               sb.append(" victoryRateR=\"0\" ");
               sb.append(" drawRateR=\"0\" ");
               sb.append(" loseRateR=\"0\" ");
               sb.append(" victoryRate=\"0\" ");
               sb.append(" drawRate=\"0\" ");
               sb.append(" loseRate=\"0\" ");
            }

            sb.append("></odds>");
         }
      }

      sb.append("</body>");
      return ByteCodeUtil.xmlToObject(sb.toString());
   }

   private void check(Map map) {
      if(map != null) {
         if(map.get("WIN") == null) {
            map.put("WIN", Integer.valueOf(0));
         }

         if(map.get("FLAT") == null) {
            map.put("FLAT", Integer.valueOf(0));
         }

         if(map.get("LOSE") == null) {
            map.put("LOSE", Integer.valueOf(0));
         }
      } else {
         HashMap map1 = new HashMap();
         map1.put("WIN", Integer.valueOf(0));
         map1.put("FLAT", Integer.valueOf(0));
         map1.put("LOSE", Integer.valueOf(0));
      }

   }

   public static void main(String[] args) {
      String string = "<root><request><query lotteryCode=\"400\" issue=\"221052\" sn=\"001\"></query></request></root>";
      IAdapter adapter = (IAdapter)SpringUtils.getBean("appFBMatchInfoQueryAdapter");
      System.out.println(adapter.execute(ByteCodeUtil.xmlToObject(string)).toString());
   }
}
